==> lxqt-notificationd_2.2.0.orig.tar.xz: lxqt-notificationd-2.2.0/config/translations/lxqt-config-notificationd_hr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="hr">
<context>
    <name>AdvancedSettings</name>
    <message>
        <location filename="../advancedsettings.ui" line="67"/>
        <source>Duration</source>
        <translation>Trajanje</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="79"/>
        <source>Some notifications set their own on-screen duration.</source>
        <translation>Neke obavijesti postavljaju vlastita trajanja prikaza.</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="91"/>
        <source>Default duration:</source>
        <translation>Standardno trajanje:</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="98"/>
        <source> sec</source>
        <translation> s</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="17"/>
        <source>Unattended Notifications</source>
        <translation>Nepročitane obavijesti</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="25"/>
        <source>How many to save:</source>
        <translation>Koliko obavijesti čuvati:</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="39"/>
        <location filename="../advancedsettings.ui" line="49"/>
        <source>Use the top of the notification as shown.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="42"/>
        <source>Ignore these notifications:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="126"/>
        <source>Screen</source>
        <translation>Ekran</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="132"/>
        <source>When unchecked the notification will always show on primary screen</source>
        <translation>Kad nije označeno, obavijest će se uvijek prikazati na primarnom ekranu</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="135"/>
        <source>Show notifications on screen with the mouse</source>
        <translation>Prikaži obavijesti na ekranu s mišem</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="145"/>
        <source>Do Not Disturb</source>
        <translation>Ne smetaj</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="151"/>
        <source>Only save notifications</source>
        <translation>Spremi samo obavijesti</translation>
    </message>
</context>
<context>
    <name>BasicSettings</name>
    <message>
        <location filename="../basicsettings.ui" line="17"/>
        <source>Sizes</source>
        <translation>Veličine</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="25"/>
        <source>Width:</source>
        <translation>Širina:</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="32"/>
        <location filename="../basicsettings.ui" line="56"/>
        <source> px</source>
        <translation> px</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="49"/>
        <source>Spacing:</source>
        <translation>Razmak:</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="68"/>
        <source>Position on screen</source>
        <translation>Položaj na ekranu</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="227"/>
        <source>Preview</source>
        <translation>Pregled</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="65"/>
        <source>&lt;b&gt;Warning:&lt;/b&gt; notifications daemon is slow to respond.
Keep trying to connect…</source>
        <translation>&lt;b&gt;Oprez:&lt;/b&gt; demon obavijesti reagira sporo.
Nastavi se povezivati …</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="74"/>
        <source>&lt;b&gt;Warning:&lt;/b&gt; No notifications daemon is running.
A fallback will be used.</source>
        <translation>&lt;b&gt;Upozorenje:&lt;/b&gt; Nijedan demon za obavijesti nije pokrenut.
Koristit će se rezervni.</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="77"/>
        <source>&lt;b&gt;Warning:&lt;/b&gt; A third-party notifications daemon (%1) is running.
These settings won&apos;t have any effect on it!</source>
        <translation>&lt;b&gt;Upozorenje:&lt;/b&gt; Pokrenut je jedan strani demon za obavijesti (%1).
Ove postavke na njega ne utječu!</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="142"/>
        <source>at top left</source>
        <translation>gore lijevo</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="144"/>
        <source>at top center</source>
        <translation>gore centrirano</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="146"/>
        <source>at top right</source>
        <translation>gore desno</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="148"/>
        <source>at center left</source>
        <translation>centrirano lijevo</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="150"/>
        <source>at center right</source>
        <translation>centrirano desno</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="152"/>
        <source>at bottom left</source>
        <translation>dolje lijevo</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="154"/>
        <source>at bottom center</source>
        <translation>dolje centrirano</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="156"/>
        <source>at bottom right</source>
        <translation>dolje desno</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="158"/>
        <source>Notification demo </source>
        <translation>Prikaz obavijesti </translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="159"/>
        <source>This is a test notification.
 All notifications will now appear here on LXQt.</source>
        <translation>Ovo je testna obavijest.
Sve obavijesti će se sada ovdje pojaviti na LXQt-u.</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="41"/>
        <source>Desktop Notifications</source>
        <translation>Obavijesti na radnoj površini</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="44"/>
        <source>General Settings</source>
        <translation>Opće postavke</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="48"/>
        <source>Appearance</source>
        <translation>Izgled</translation>
    </message>
</context>
</TS>

==> lxqt-notificationd_2.3.0.orig.tar.xz: lxqt-notificationd-2.3.0/config/translations/lxqt-config-notificationd_hr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="hr">
<context>
    <name>AdvancedSettings</name>
    <message>
        <location filename="../advancedsettings.ui" line="17"/>
        <source>Duration</source>
        <translation>Trajanje</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="29"/>
        <source>Some notifications set their own on-screen duration.</source>
        <translation>Neke obavijesti postavljaju vlastita trajanja prikaza.</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="41"/>
        <source>Default duration:</source>
        <translation>Standardno trajanje:</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="48"/>
        <source> sec</source>
        <translation> s</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="63"/>
        <source>Unattended Notifications</source>
        <translation>Nepročitane obavijesti</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="71"/>
        <source>How many to save:</source>
        <translation>Koliko obavijesti čuvati:</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="85"/>
        <location filename="../advancedsettings.ui" line="95"/>
        <source>Use the top of the notification as shown.</source>
        <translation>Koristi gornji dio obavijesti kao što je prikazano.</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="88"/>
        <source>Ignore these notifications:</source>
        <translation>Zanemari ove obavijesti:</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="129"/>
        <source>Screen</source>
        <translation>Ekran</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="135"/>
        <source>When unchecked the notification will always show on primary screen</source>
        <translation>Kad nije označeno, obavijest će se uvijek prikazati na primarnom ekranu</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="138"/>
        <source>Show notifications on screen with the mouse</source>
        <translation>Prikaži obavijesti na ekranu s mišem</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="113"/>
        <source>Do Not Disturb</source>
        <translation>Ne smetaj</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="119"/>
        <source>Only save notifications</source>
        <translation>Spremi samo obavijesti</translation>
    </message>
</context>
<context>
    <name>BasicSettings</name>
    <message>
        <location filename="../basicsettings.ui" line="17"/>
        <source>Sizes</source>
        <translation>Veličine</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="25"/>
        <source>Width:</source>
        <translation>Širina:</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="32"/>
        <location filename="../basicsettings.ui" line="56"/>
        <source> px</source>
        <translation> px</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="49"/>
        <source>Spacing:</source>
        <translation>Razmak:</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="68"/>
        <source>Position on screen</source>
        <translation>Položaj na ekranu</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="227"/>
        <source>Preview</source>
        <translation>Pregled</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="65"/>
        <source>&lt;b&gt;Warning:&lt;/b&gt; notifications daemon is slow to respond.
Keep trying to connect…</source>
        <translation>&lt;b&gt;Oprez:&lt;/b&gt; demon obavijesti reagira sporo.
Nastavi se povezivati …</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="74"/>
        <source>&lt;b&gt;Warning:&lt;/b&gt; No notifications daemon is running.
A fallback will be used.</source>
        <translation>&lt;b&gt;Upozorenje:&lt;/b&gt; Nijedan demon za obavijesti nije pokrenut.
Koristit će se rezervni.</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="77"/>
        <source>&lt;b&gt;Warning:&lt;/b&gt; A third-party notifications daemon (%1) is running.
These settings won&apos;t have any effect on it!</source>
        <translation>&lt;b&gt;Upozorenje:&lt;/b&gt; Pokrenut je jedan strani demon za obavijesti (%1).
Ove postavke na njega ne utječu!</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="142"/>
        <source>at top left</source>
        <translation>gore lijevo</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="144"/>
        <source>at top center</source>
        <translation>gore centrirano</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="146"/>
        <source>at top right</source>
        <translation>gore desno</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="148"/>
        <source>at center left</source>
        <translation>centrirano lijevo</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="150"/>
        <source>at center right</source>
        <translation>centrirano desno</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="152"/>
        <source>at bottom left</source>
        <translation>dolje lijevo</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="154"/>
        <source>at bottom center</source>
        <translation>dolje centrirano</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="156"/>
        <source>at bottom right</source>
        <translation>dolje desno</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="158"/>
        <source>Notification demo </source>
        <translation>Prikaz obavijesti </translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="159"/>
        <source>This is a test notification.
 All notifications will now appear here on LXQt.</source>
        <translation>Ovo je testna obavijest.
Sve obavijesti će se sada ovdje pojaviti na LXQt-u.</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="41"/>
        <source>Desktop Notifications</source>
        <translation>Obavijesti na radnoj površini</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="44"/>
        <source>General Settings</source>
        <translation>Opće postavke</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="48"/>
        <source>Appearance</source>
        <translation>Izgled</translation>
    </message>
</context>
</TS>
